@@ -1,4 +1,15 @@
 # (C) Copyright 2015-2017 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import collections
 from concurrent import futures
@@ -6,7 +17,6 @@ import Queue
 import threading
 
 import eventlet
-from eventlet.green import time
 import multiprocessing
 
 import monasca_agent.collector.checks
@@ -44,7 +54,8 @@ class ServicesCheck(monasca_agent.collector.checks.AgentCheck):
     """
 
     def __init__(self, name, init_config, agent_config, instances):
-        monasca_agent.collector.checks.AgentCheck.__init__(self, name, init_config, agent_config, instances)
+        monasca_agent.collector.checks.AgentCheck.__init__(
+            self, name, init_config, agent_config, instances)
 
         # A dictionary to keep track of service statuses
         self.statuses = {}
