@@ -1,5 +1,17 @@
 #!/bin/env python
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 """Monitoring Agent plugin for HTTP/API checks.
 
 """
@@ -33,9 +45,6 @@ class HTTPCheck(services_checks.ServicesCheck):
         # init the keystone client if instance has use_keystone
         self._api_config = cfg.Config().get_config('Api')
         self._ksclients = {}
-
-        init_keystone_config = init_config.get('keystone_config', None)
-
         for instance in instances:
             addr, username, password, timeout, headers, response_time, \
                 disable_ssl_validation, use_keystone, keystone_config, \
@@ -43,11 +52,7 @@ class HTTPCheck(services_checks.ServicesCheck):
             if use_keystone:
                 # keystone is a singleton. It will be initialized once,
                 # the first config instance used.
-                if init_keystone_config:
-                    ksclient = keystone.Keystone(init_keystone_config)
-                elif keystone_config:
-                    # Using Keystone config in each instance is deprecated
-                    # in Rocky.
+                if keystone_config:
                     ksclient = keystone.Keystone(keystone_config)
                 else:
                     ksclient = keystone.Keystone(self._api_config)
@@ -100,7 +105,9 @@ class HTTPCheck(services_checks.ServicesCheck):
             try:
                 self.log.debug("Connecting to %s" % addr)
                 if disable_ssl_validation:
-                    self.log.info("Skipping SSL certificate validation for %s based on configuration" % addr)
+                    self.log.info(
+                        "Skipping SSL certificate validation for %s based on configuration" %
+                        addr)
                 h = Http(timeout=timeout, disable_ssl_certificate_validation=disable_ssl_validation)
                 if username is not None and password is not None:
                     h.add_credentials(username, password)
@@ -193,7 +200,8 @@ class HTTPCheck(services_checks.ServicesCheck):
             if re.search(pattern, result_string, re.DOTALL):
                 self.log.debug("Pattern match successful")
             else:
-                error_string = 'Pattern match failed! "{0}" not in "{1}"'.format(pattern, result_string)
+                error_string = 'Pattern match failed! "{0}" not in "{1}"'.format(
+                    pattern, result_string)
                 self.log.info(error_string)
                 # maximum length of value_meta including {'error':''} is 2048
                 # Cutting it down to 1024 here so we don't clutter the
