@@ -1,4 +1,15 @@
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import os
 import re
@@ -66,8 +77,9 @@ class MySql(checks.AgentCheck):
         return {"PyMySQL": version}
 
     def check(self, instance):
-        host, port, user, password, mysql_sock, ssl_ca, ssl_key, ssl_cert, defaults_file, options = self._get_config(
-            instance)
+        host, port, user, password, mysql_sock, ssl_ca, ssl_key, ssl_cert, defaults_file, \
+            options = self._get_config(
+                instance)
         self.ssl_options = {}
         if ssl_ca is not None:
             self.ssl_options['ca'] = ssl_ca
@@ -102,7 +114,8 @@ class MySql(checks.AgentCheck):
         defaults_file = instance.get('defaults_file', '')
         options = instance.get('options', {})
 
-        return host, port, user, password, mysql_sock, ssl_ca, ssl_key, ssl_cert, defaults_file, options
+        return host, port, user, password, mysql_sock, ssl_ca, ssl_key, ssl_cert, \
+            defaults_file, options
 
     def _connect(self, host, port, mysql_sock, user, password, defaults_file):
         try:
@@ -212,7 +225,9 @@ class MySql(checks.AgentCheck):
                 greater_502 = True
 
         except Exception as exception:
-            self.log.warn("Cannot compute mysql version, assuming older than 5.0.2: %s" % str(exception))
+            self.log.warn(
+                "Cannot compute mysql version, assuming older than 5.0.2: %s" %
+                str(exception))
 
         self.greater_502[host] = greater_502
 
