@@ -1,4 +1,16 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 """Parses the response from zookeeper's `stat` admin command, which looks like:
 
 ```
@@ -38,7 +50,8 @@ class Zookeeper(AgentCheck):
         host = instance.get('host', 'localhost')
         port = int(instance.get('port', 2181))
         timeout = float(instance.get('timeout', 3.0))
-        dimensions = self._set_dimensions({'component': 'zookeeper', 'service': 'zookeeper'}, instance)
+        dimensions = self._set_dimensions(
+            {'component': 'zookeeper', 'service': 'zookeeper'}, instance)
 
         sock = socket.socket()
         sock.settimeout(timeout)
