@@ -1,4 +1,16 @@
 # (C) Copyright 2015-2017 Hewlett Packard Enterprise Development LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 """ Aggregation classes used by the collector and statsd to batch messages sent to the forwarder.
 """
 import json
@@ -106,7 +118,10 @@ class MetricsAggregator(object):
         cur_time = time()
         if timestamp is not None:
             if cur_time - int(timestamp) > self.recent_point_threshold:
-                log.debug("Discarding {0} - ts = {1}, current ts = {2} ".format(name, timestamp, cur_time))
+                log.debug(
+                    "Discarding {0} - ts = {1}, current ts = {2} ".format(name,
+                                                                          timestamp,
+                                                                          cur_time))
                 self.num_discarded_old_points += 1
                 return
         else:
