@@ -1,4 +1,15 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 """Classes to aid in configuration of the agent."""
 
@@ -15,8 +26,8 @@ class Plugins(collections.defaultdict):
 
     """A container for the plugin configurations used by the monasca-agent.
 
-        This is essentially a defaultdict(dict) but put into a class primarily to make the interface clear, also
-        to add a couple of helper methods.
+        This is essentially a defaultdict(dict) but put into a class primarily to make the
+        interface clear, also to add a couple of helper methods.
         Each plugin config is stored with the key being its config name (excluding .yaml).
         The value a dict which will convert to yaml.
     """
@@ -33,16 +44,17 @@ class Plugins(collections.defaultdict):
         """Do a deep merge with precedence going to other (as is the case with update).
 
         """
-        # Implemented as a function so it can be used for arbitrary dictionaries not just self, this is needed
-        # for the recursive nature of the merge.
+        # Implemented as a function so it can be used for arbitrary dictionaries not just self,
+        # this is needed for the recursive nature of the merge.
         deep_merge(self, other)
 
 
 def deep_merge(adict, other):
-    """A recursive merge of two dictionaries including combining of any lists within the data structure.
+    """A recursive merge of two dictionaries including combining of any lists within the data
+    structure.
 
     """
-    for key, value in other.iteritems():
+    for key, value in other.items():
         if key in adict:
             if isinstance(adict[key], dict) and isinstance(value, dict):
                 deep_merge(adict[key], value)
@@ -53,8 +65,10 @@ def deep_merge(adict, other):
 
 
 def merge_by_name(first, second):
-    """Merge a list of dictionaries replacing any dictionaries with the same 'name' value rather than merging.
-        The precedence goes to first.
+    """Merge a list of dictionaries replacing any dictionaries with the same 'name' value rather
+    than merging.
+
+    The precedence goes to first.
     """
     first_names = [i['name'] for i in first if 'name' in i]
     for item in second:
