@@ -1,4 +1,15 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import logging
 
@@ -9,16 +20,20 @@ log = logging.getLogger(__name__)
 
 
 class ArgsPlugin(Plugin):
-    """Base plugin for detection plugins that take arguments for configuration rather than do detection."""
+    """Base plugin for detection plugins that take arguments for configuration rather than do
+    detection.
+    """
 
     def _build_instance(self, arg_list):
-        """If a value for each arg in the arg_list was specified build it into an instance dictionary. Also check for dimensions and add if they were specified.
+        """If a value for each arg in the arg_list was specified build it into an instance
+        dictionary. Also check for dimensions and add if they were specified.
         :param arg_list: Arguments to include
         :return: instance dictionary
         """
         instance = {}
         if 'dimensions' in self.args:
-            instance['dimensions'] = dict(item.strip().split(":") for item in self.args['dimensions'].split(","))
+            instance['dimensions'] = dict(item.strip().split(":")
+                                          for item in self.args['dimensions'].split(","))
         for arg in arg_list:
             if arg in self.args:
                 instance[arg] = self.args[arg]
