@@ -1,4 +1,15 @@
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import logging
 import os
@@ -95,7 +106,8 @@ class Apache(monasca_setup.detection.Plugin):
             [self._apache_process_name], 'apache'))
         log.info("\tWatching the apache webserver process.")
 
-        error_msg = '\n\t*** The Apache plugin is not configured ***\n\tPlease correct and re-run monasca-setup.'
+        error_msg = '\n\t*** The Apache plugin is not configured ***\n\tPlease correct and re-run'
+        'monasca-setup.'
         # Attempt login, requires either an empty root password from localhost
         # or relying on a configured /root/.apache.cnf
         if self.dependencies_installed():
@@ -167,7 +179,9 @@ class Apache(monasca_setup.detection.Plugin):
                 log.error(exception_msg)
                 raise Exception(exception_msg)
         else:
-            log.error('\tThe dependencies for Apache Web Server are not installed or unavailable.' + error_msg)
+            log.error(
+                '\tThe dependencies for Apache Web Server are not installed or unavailable.' +
+                error_msg)
 
         return config
 
