@@ -1,11 +1,23 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
 # Copyright 2016 FUJITSU LIMITED
 # Copyright 2017 SUSE Linux GmbH
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 """Classes for monitoring the monitoring server stack.
 
     Covering mon-persister, mon-api and mon-thresh.
-    Kafka, mysql, vertica and influxdb are covered by other detection plugins. Mon-notification uses statsd.
+    Kafka, mysql, vertica and influxdb are covered by other detection plugins. Mon-notification
+    uses statsd.
 """
 
 import logging
@@ -17,7 +29,6 @@ from six.moves import configparser
 import monasca_setup.agent_config
 import monasca_setup.detection
 from monasca_setup.detection import find_process_cmdline
-from monasca_setup.detection import find_process_name
 from monasca_setup.detection.utils import get_agent_username
 from monasca_setup.detection.utils import watch_process
 from monasca_setup.detection.utils import watch_process_by_username
@@ -293,8 +304,19 @@ class MonThresh(monasca_setup.detection.Plugin):
         config = monasca_setup.agent_config.Plugins()
         for process in ['storm.daemon.nimbus', 'storm.daemon.supervisor', 'storm.daemon.worker']:
             if find_process_cmdline(process) is not None:
-                config.merge(watch_process([process], 'monitoring', 'apache-storm', exact_match=False, detailed=False))
-        config.merge(watch_process_by_username('storm', 'monasca-thresh', 'monitoring', 'apache-storm'))
+                config.merge(
+                    watch_process(
+                        [process],
+                        'monitoring',
+                        'apache-storm',
+                        exact_match=False,
+                        detailed=False))
+        config.merge(
+            watch_process_by_username(
+                'storm',
+                'monasca-thresh',
+                'monitoring',
+                'apache-storm'))
         return config
 
     def dependencies_installed(self):
@@ -305,11 +327,12 @@ def dropwizard_health_check(service, component, url):
     """Setup a dropwizard heathcheck to be watched by the http_check plugin."""
     config = monasca_setup.agent_config.Plugins()
     config['http_check'] = {'init_config': None,
-                            'instances': [{'name': "{0}-{1} healthcheck".format(service, component),
-                                           'url': url,
-                                           'timeout': 5,
-                                           'include_content': False,
-                                           'dimensions': {'service': service, 'component': component}}]}
+                            'instances': [
+                                {'name': "{0}-{1} healthcheck".format(service, component),
+                                 'url': url,
+                                 'timeout': 5,
+                                 'include_content': False,
+                                 'dimensions': {'service': service, 'component': component}}]}
     return config
 
 
@@ -320,7 +343,8 @@ def dropwizard_metrics(service, component, url, whitelist):
                               'instances': [{'name': "{0}-{1} metrics".format(service, component),
                                              'url': url,
                                              'timeout': 5,
-                                             'dimensions': {'service': service, 'component': component},
+                                             'dimensions': {'service': service,
+                                                            'component': component},
                                              'whitelist': whitelist}]}
     return config
 
@@ -462,56 +486,55 @@ class _MonPersisterJavaHelper(_DropwizardJavaHelper):
         for idx in range(alarm_num_threads):
             new_thread = {
                 "name": "alarm-state-transitions-added-to-batch-counter[{0}]".format(idx),
-                "path": "counters/monasca.persister.pipeline.event.AlarmStateTransitionHandler[alarm-state-transition-{0}].alarm-state-transitions-added-to-batch-counter/count".format(idx),
-                "type": "rate"
-            }
+                "path": "counters/monasca.persister.pipeline.event."
+                        "AlarmStateTransitionHandler[alarm-state-transition-{0}]."
+                        "alarm-state-transitions-added-to-batch-counter/count".format(idx),
+                "type": "rate"}
             whitelist.append(new_thread)
         for idx in range(metric_num_threads):
             new_thread = {
                 "name": "metrics-added-to-batch-counter[{0}]".format(idx),
-                "path": "counters/monasca.persister.pipeline.event.MetricHandler[metric-{0}].metrics-added-to-batch-counter/count".format(idx),
-                "type": "rate"
-            }
+                "path": "counters/monasca.persister.pipeline.event.MetricHandler[metric-{0}]."
+                        "metrics-added-to-batch-counter/count".format(idx),
+                "type": "rate"}
             whitelist.append(new_thread)
 
     def _add_vertica_metrics(self, whitelist):
-        whitelist.extend([
-            {
-                "name": "monasca.persister.repository.vertica.VerticaMetricRepo.definition-cache-hit-meter",
-                "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo.definition-cache-hit-meter/count",
-                "type": "rate"
-            },
-            {
-                "name": "monasca.persister.repository.vertica.VerticaMetricRepo.definition-cache-miss-meter",
-                "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo.definition-cache-miss-meter/count",
-                "type": "rate"
-            },
-            {
-                "name": "monasca.persister.repository.vertica.VerticaMetricRepo.definition-dimension-cache-hit-meter",
-                "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo.definition-dimension-cache-hit-meter/count",
-                "type": "rate"
-            },
-            {
-                "name": "monasca.persister.repository.vertica.VerticaMetricRepo.definition-dimension-cache-miss-meter",
-                "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo.definition-dimension-cache-miss-meter/count",
-                "type": "rate"
-            },
-            {
-                "name": "monasca.persister.repository.vertica.VerticaMetricRepo.dimension-cache-hit-meter",
-                "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo.dimension-cache-hit-meter/count",
-                "type": "rate"
-            },
-            {
-                "name": "monasca.persister.repository.vertica.VerticaMetricRepo.dimension-cache-miss-meter",
-                "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo.dimension-cache-miss-meter/count",
-                "type": "rate"
-            },
-            {
-                "name": "monasca.persister.repository.vertica.VerticaMetricRepo.measurement-meter",
-                "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo.measurement-meter/count",
-                "type": "rate"
-            }
-        ])
+        whitelist.extend(
+            [{"name": "monasca.persister.repository.vertica.VerticaMetricRepo."
+                      "definition-cache-hit-meter",
+              "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo."
+                      "definition-cache-hit-meter/count",
+              "type": "rate"},
+             {"name": "monasca.persister.repository.vertica.VerticaMetricRepo."
+                      "definition-cache-miss-meter",
+              "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo."
+                      "definition-cache-miss-meter/count",
+              "type": "rate"},
+                {"name": "monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "definition-dimension-cache-hit-meter",
+                 "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "definition-dimension-cache-hit-meter/count",
+                 "type": "rate"},
+                {"name": "monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "definition-dimension-cache-miss-meter",
+                 "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "definition-dimension-cache-miss-meter/count",
+                 "type": "rate"},
+                {"name": "monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "dimension-cache-hit-meter",
+                 "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "dimension-cache-hit-meter/count",
+                 "type": "rate"},
+                {"name": "monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "dimension-cache-miss-meter",
+                 "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "dimension-cache-miss-meter/count",
+                 "type": "rate"},
+                {"name": "monasca.persister.repository.vertica.VerticaMetricRepo.measurement-meter",
+                 "path": "meters/monasca.persister.repository.vertica.VerticaMetricRepo."
+                         "measurement-meter/count",
+                 "type": "rate"}])
 
     def _monitor_endpoints(self, config, metrics):
         admin_connector = self._cfg['server']['adminConnectors'][0]
