@@ -1,4 +1,15 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import logging
 import urllib2
@@ -131,7 +142,9 @@ class RabbitMQ(monasca_setup.detection.Plugin):
         # First watch the process
         config.merge(monasca_setup.detection.watch_process(['epmd'], 'rabbitmq', detailed=False))
         log.info("\tWatching the rabbitmq-server process.")
-        config.merge(monasca_setup.detection.watch_process_by_username('rabbitmq', 'rabbitmq', 'rabbitmq'))
+        config.merge(
+            monasca_setup.detection.watch_process_by_username(
+                'rabbitmq', 'rabbitmq', 'rabbitmq'))
         log.info("\tWatching all processes owned by the rabbitmq user.")
 
         if not self._watch_api:
